// libs/core/src/utils/helpers/custom-element-scoping.ts
import { html as litHtml } from "lit";
import { customElement } from "lit/decorators.js";
var VER_SUFFIX = "-296eb7";
var elementLookupTable = /* @__PURE__ */ new Map();
var gdsCustomElement = (tagName) => {
  if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
    elementLookupTable.set(tagName, tagName);
    return customElement(tagName);
  }
  const versionedTagName = tagName + VER_SUFFIX;
  elementLookupTable.set(tagName, versionedTagName);
  if (customElements.get(versionedTagName))
    return (_classOrDescriptor) => false;
  return customElement(versionedTagName);
};
var templateCache = /* @__PURE__ */ new WeakMap();
function applyElementScoping(strings, ...values) {
  let modstrings = templateCache.get(strings);
  if (!modstrings) {
    modstrings = replaceTags(strings);
    modstrings.raw = replaceTags(strings.raw);
    templateCache.set(strings, modstrings);
  }
  return [modstrings, ...values];
}
var replaceTags = (inStr) => inStr.map((s) => {
  for (const [key, value] of elementLookupTable.entries()) {
    s = s.replace(new RegExp(`${key}(?![-a-z])`, "mg"), value);
  }
  return s;
});
function htmlTemplateTagFactory(extendedTag) {
  return (strings, ...values) => {
    if (globalThis.GDS_DISABLE_VERSIONED_ELEMENTS) {
      return extendedTag(strings, ...values);
    }
    const [modstrings, ...modvalues] = applyElementScoping(strings, ...values);
    return extendedTag(modstrings, ...modvalues);
  };
}
var html = htmlTemplateTagFactory(litHtml);
function getScopedTagName(tagName) {
  var _a;
  return (_a = elementLookupTable.get(tagName)) != null ? _a : tagName;
}
function getUnscopedTagName(tagName) {
  var _a;
  return (_a = [...elementLookupTable.entries()].find(
    ([, value]) => value === tagName
  )) == null ? void 0 : _a[0];
}

export {
  VER_SUFFIX,
  gdsCustomElement,
  htmlTemplateTagFactory,
  html,
  getScopedTagName,
  getUnscopedTagName
};
