// libs/core/src/utils/decorators/observe-light-dom.ts
function observeLightDOM(observerConfig = {
  attributes: true,
  childList: true,
  subtree: false,
  characterData: true
}) {
  return (proto, _propertyKey, descriptor) => {
    let observer;
    const connectedCallback = proto.connectedCallback;
    const disconnectedCallback = proto.disconnectedCallback;
    proto.connectedCallback = function() {
      connectedCallback == null ? void 0 : connectedCallback.call(this);
      const callback = (_mutationList, _observer) => {
        var _a;
        (_a = descriptor.value) == null ? void 0 : _a.call(this);
      };
      observer = new MutationObserver(callback);
      observer.observe(this, observerConfig);
    };
    proto.disconnectedCallback = function() {
      disconnectedCallback == null ? void 0 : disconnectedCallback.call(this);
      observer.disconnect();
    };
  };
}

// libs/core/src/utils/decorators/watch-media-query.ts
function watchMediaQuery(q) {
  return (proto, _propertyKey, descriptor) => {
    const mediaQuery = window.matchMedia(q);
    const connectedCallback = proto.connectedCallback;
    const disconnectedCallback = proto.disconnectedCallback;
    proto.connectedCallback = function() {
      var _a;
      connectedCallback == null ? void 0 : connectedCallback.call(this);
      const listener = (e) => {
        var _a2;
        (_a2 = descriptor.value) == null ? void 0 : _a2.call(this, e.matches);
      };
      mediaQuery.addEventListener("change", listener);
      this.disconnectedCallback = function() {
        disconnectedCallback == null ? void 0 : disconnectedCallback.call(this);
        mediaQuery.removeEventListener("change", listener);
      };
      (_a = descriptor.value) == null ? void 0 : _a.call(this, mediaQuery.matches);
    };
  };
}

export {
  observeLightDOM,
  watchMediaQuery
};
