import { GdsContainer } from '../container';
/**
 * The `gds-flex` component is a flex element that can be used to wrap other components and control the layout of its children.
 *
 * It can be used in combination with other elements like `gds-grid`, `gds-card`, `gds-img`, `gds-text` etc.
 *
 * @element gds-flex
 * @status beta
 *
 */
export declare class GdsFlex extends GdsContainer {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the gap property of the flex.
     * Supports all space tokens as value.
     *
     * You can apply gap in each column and row like this:
     * ```html
     * <gds-flex gap="m s"></gds-flex>
     * ```
     *
     * The `gap` can be applied on `flex` using shorthand like gap="m s"
     *
     * Gap also support breakpoint syntax like this:
     * ```html
     * <gds-flex gap="xs{s} m{m} l{xl}"></gds-flex>
     * ```
     * The above example will apply the gap style of `xs` for `small` devices, `m` for `medium` devices, and `xl` for large devices.
     *
     */
    gap?: string;
    /**
     * Controls the align-items property of the flex.
     * Supports all valid CSS align-items values.
     */
    align?: string;
    /**
     * Controls the justify-content property of the flex.
     * Supports all valid CSS justify-content values.
     */
    justify?: string;
    /**
     * Controls the flex-direction property of the flex.
     * Supports all valid CSS flex-direction values.
     */
    direction?: string;
    connectedCallback(): void;
    render(): any;
}
