import type { LitElement } from 'lit';
type Handler = (matches: boolean) => void;
/**
 * Media queries expressing standard breakpoints.
 * TODO: These should probably be imported from somehere, so that they are always in sync with CSS.
 */
export declare const standardBreakpoints: {
    sm: string;
    md: string;
    lg: string;
    xl: string;
};
/**
 * Runs when the match state of the specified media query changes.
 *
 * @param q The media query to watch.
 *
 * Usage:
 * ```javascript
 * \@watchMediaQuery('(max-width: 576px)')
 * handleMobileLayout(matches) {
 *  if (matches) {
 *   // Do something when the media query matches
 *  } else
 *   // Do something when the media query no longer matches
 *  }
 * }
 * ```
 */
export declare function watchMediaQuery(q: string): <ElemClass extends LitElement>(proto: ElemClass, _propertyKey: string, descriptor: TypedPropertyDescriptor<Handler>) => void;
export {};
